@@ -1,4 +1,4 @@
-/* idna.c	Convert to or from IDN strings.
+/* idna.c --- Convert to or from IDN strings.
  * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of GNU Libidn.
@@ -15,11 +15,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU Libidn; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  *
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -36,12 +36,13 @@
 /* Core functions */
 
 /**
- * idna_to_ascii_4i
+ * idna_to_ascii_4i - convert Unicode domain name label to text
  * @in: input array with unicode code points.
  * @inlen: length of input array with unicode code points.
  * @out: output zero terminated string that must have room for at
  *       least 63 characters plus the terminating zero.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * The ToASCII operation takes a sequence of Unicode code points that make
  * up one label and transforms it into a sequence of code points in the
@@ -63,7 +64,7 @@
  * operation multiple times has exactly the same effect as applying it just
  * once.
  *
- * Return value: Returns 0 on success, or an error code.
+ * Return value: Returns 0 on success, or an #Idna_rc error code.
  */
 int
 idna_to_ascii_4i (const uint32_t * in, size_t inlen, char *out, int flags)
@@ -376,13 +377,14 @@ step3:
 }
 
 /**
- * idna_to_unicode_44i
+ * idna_to_unicode_44i - convert domain name label to Unicode
  * @in: input array with unicode code points.
  * @inlen: length of input array with unicode code points.
  * @out: output array with unicode code points.
  * @outlen: on input, maximum size of output array with unicode code points,
  *          on exit, actual size of output array with unicode code points.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * The ToUnicode operation takes a sequence of Unicode code points
  * that make up one label and returns a sequence of Unicode code
@@ -402,13 +404,12 @@ step3:
  * AllowUnassigned flag, and the UseSTD3ASCIIRules flag. The output of
  * ToUnicode is always a sequence of Unicode code points.
  *
- * Return value: Returns error condition, but it must only be used for
- *               debugging purposes.  The output buffer is always
- *               guaranteed to contain the correct data according to
- *               the specification (sans malloc induced errors).  NB!
- *               This means that you normally ignore the return code
- *               from this function, as checking it means breaking the
- *               standard.
+ * Return value: Returns #Idna_rc error condition, but it must only be
+ *   used for debugging purposes.  The output buffer is always
+ *   guaranteed to contain the correct data according to the
+ *   specification (sans malloc induced errors).  NB!  This means that
+ *   you normally ignore the return code from this function, as
+ *   checking it means breaking the standard.
  */
 int
 idna_to_unicode_44i (const uint32_t * in, size_t inlen,
@@ -438,16 +439,17 @@ idna_to_unicode_44i (const uint32_t * in, size_t inlen,
 /* Wrappers that handle several labels */
 
 /**
- * idna_to_ascii_4z:
+ * idna_to_ascii_4z - convert Unicode domain name label to text
  * @input: zero terminated input Unicode string.
  * @output: pointer to newly allocated output string.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert UCS-4 domain name to ASCII string.  The domain name may
  * contain several labels, separated by dots.  The output buffer must
  * be deallocated by the caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_ascii_4z (const uint32_t * input, char **output, int flags)
@@ -533,16 +535,17 @@ idna_to_ascii_4z (const uint32_t * input, char **output, int flags)
 }
 
 /**
- * idna_to_ascii_8z:
+ * idna_to_ascii_8z - convert Unicode domain name label to text
  * @input: zero terminated input UTF-8 string.
  * @output: pointer to newly allocated output string.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert UTF-8 domain name to ASCII string.  The domain name may
  * contain several labels, separated by dots.  The output buffer must
  * be deallocated by the caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_ascii_8z (const char *input, char **output, int flags)
@@ -564,17 +567,18 @@ idna_to_ascii_8z (const char *input, char **output, int flags)
 }
 
 /**
- * idna_to_ascii_lz:
+ * idna_to_ascii_lz - convert Unicode domain name label to text
  * @input: zero terminated input string encoded in the current locale's
  *   character set.
  * @output: pointer to newly allocated output string.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert domain name in the locale's encoding to ASCII string.  The
  * domain name may contain several labels, separated by dots.  The
  * output buffer must be deallocated by the caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_ascii_lz (const char *input, char **output, int flags)
@@ -594,17 +598,18 @@ idna_to_ascii_lz (const char *input, char **output, int flags)
 }
 
 /**
- * idna_to_unicode_4z4z:
+ * idna_to_unicode_4z4z - convert domain name label to Unicode
  * @input: zero-terminated Unicode string.
  * @output: pointer to newly allocated output Unicode string.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert possibly ACE encoded domain name in UCS-4 format into a
  * UCS-4 string.  The domain name may contain several labels,
  * separated by dots.  The output buffer must be deallocated by the
  * caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_unicode_4z4z (const uint32_t * input, uint32_t ** output, int flags)
@@ -669,17 +674,18 @@ idna_to_unicode_4z4z (const uint32_t * input, uint32_t ** output, int flags)
 }
 
 /**
- * idna_to_unicode_8z4z:
+ * idna_to_unicode_8z4z - convert domain name label to Unicode
  * @input: zero-terminated UTF-8 string.
  * @output: pointer to newly allocated output Unicode string.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert possibly ACE encoded domain name in UTF-8 format into a
  * UCS-4 string.  The domain name may contain several labels,
  * separated by dots.  The output buffer must be deallocated by the
  * caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_unicode_8z4z (const char *input, uint32_t ** output, int flags)
@@ -699,17 +705,18 @@ idna_to_unicode_8z4z (const char *input, uint32_t ** output, int flags)
 }
 
 /**
- * idna_to_unicode_8z8z:
+ * idna_to_unicode_8z8z - convert domain name label to Unicode
  * @input: zero-terminated UTF-8 string.
  * @output: pointer to newly allocated output UTF-8 string.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert possibly ACE encoded domain name in UTF-8 format into a
  * UTF-8 string.  The domain name may contain several labels,
  * separated by dots.  The output buffer must be deallocated by the
  * caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_unicode_8z8z (const char *input, char **output, int flags)
@@ -728,18 +735,19 @@ idna_to_unicode_8z8z (const char *input, char **output, int flags)
 }
 
 /**
- * idna_to_unicode_8zlz:
+ * idna_to_unicode_8zlz - convert domain name label to Unicode
  * @input: zero-terminated UTF-8 string.
  * @output: pointer to newly allocated output string encoded in the
  *   current locale's character set.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert possibly ACE encoded domain name in UTF-8 format into a
  * string encoded in the current locale's character set.  The domain
  * name may contain several labels, separated by dots.  The output
  * buffer must be deallocated by the caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_unicode_8zlz (const char *input, char **output, int flags)
@@ -758,19 +766,20 @@ idna_to_unicode_8zlz (const char *input, char **output, int flags)
 }
 
 /**
- * idna_to_unicode_lzlz:
+ * idna_to_unicode_lzlz - convert domain name label to Unicode
  * @input: zero-terminated string encoded in the current locale's
  *   character set.
  * @output: pointer to newly allocated output string encoded in the
  *   current locale's character set.
- * @flags: IDNA flags, e.g. IDNA_ALLOW_UNASSIGNED or IDNA_USE_STD3_ASCII_RULES.
+ * @flags: an #Idna_flags value, e.g., %IDNA_ALLOW_UNASSIGNED or
+ *   %IDNA_USE_STD3_ASCII_RULES.
  *
  * Convert possibly ACE encoded domain name in the locale's character
  * set into a string encoded in the current locale's character set.
  * The domain name may contain several labels, separated by dots.  The
  * output buffer must be deallocated by the caller.
  *
- * Return value: Returns IDNA_SUCCESS on success, or error code.
+ * Return value: Returns %IDNA_SUCCESS on success, or error code.
  **/
 int
 idna_to_unicode_lzlz (const char *input, char **output, int flags)
