@@ -1,5 +1,5 @@
-/* nfkc.c	Unicode normalization utilities.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+/* nfkc.c --- Unicode normalization utilities.
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -15,11 +15,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU Libidn; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  *
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -527,7 +527,7 @@ err_out:
  * @string: a UCS-4 encoded string.
  * @len: the maximum length of @string to use.
  *
- * Computes the canonical ordering of a string in-place. 
+ * Computes the canonical ordering of a string in-place.
  * This rearranges decomposed characters in the string
  * according to their combining classes.  See the Unicode
  * manual for more information.
@@ -926,7 +926,7 @@ g_utf8_normalize (const gchar * str, gssize len, GNormalizeMode mode)
 /* Public Libidn API starts here. */
 
 /**
- * stringprep_utf8_to_unichar:
+ * stringprep_utf8_to_unichar - convert UTF-8 to Unicode code point
  * @p: a pointer to Unicode character encoded as UTF-8
  *
  * Converts a sequence of bytes encoded as UTF-8 to a Unicode character.
@@ -942,7 +942,7 @@ stringprep_utf8_to_unichar (const char *p)
 }
 
 /**
- * stringprep_unichar_to_utf8:
+ * stringprep_unichar_to_utf8 - convert Unicode code point to UTF-8
  * @c: a ISO10646 character code
  * @outbuf: output buffer, must have at least 6 bytes of space.
  *       If %NULL, the length will be computed and returned
@@ -959,7 +959,7 @@ stringprep_unichar_to_utf8 (uint32_t c, char *outbuf)
 }
 
 /**
- * stringprep_utf8_to_ucs4:
+ * stringprep_utf8_to_ucs4 - convert UTF-8 string to UCS-4
  * @str: a UTF-8 encoded string
  * @len: the maximum length of @str to use. If @len < 0, then
  *       the string is nul-terminated.
@@ -980,7 +980,7 @@ stringprep_utf8_to_ucs4 (const char *str, ssize_t len, size_t * items_written)
 }
 
 /**
- * stringprep_ucs4_to_utf8:
+ * stringprep_ucs4_to_utf8 - convert UCS-4 string to UTF-8
  * @str: a UCS-4 encoded string
  * @len: the maximum length of @str to use. If @len < 0, then
  *       the string is terminated with a 0 character.
@@ -1006,7 +1006,7 @@ stringprep_ucs4_to_utf8 (const uint32_t * str, ssize_t len,
 }
 
 /**
- * stringprep_utf8_nfkc_normalize:
+ * stringprep_utf8_nfkc_normalize - normalize Unicode string
  * @str: a UTF-8 encoded string.
  * @len: length of @str, in bytes, or -1 if @str is nul-terminated.
  *
@@ -1034,7 +1034,7 @@ stringprep_utf8_nfkc_normalize (const char *str, ssize_t len)
 }
 
 /**
- * stringprep_ucs4_nfkc_normalize:
+ * stringprep_ucs4_nfkc_normalize - normalize Unicode string
  * @str: a Unicode string.
  * @len: length of @str array, or -1 if @str is nul-terminated.
  *
