@@ -19,6 +19,10 @@
  *
  */
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "stringprep.h"
 
 #include "gettext.h"
