@@ -19,7 +19,7 @@
  *
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -40,14 +40,18 @@
 
 #ifdef _LIBC
 # define HAVE_ICONV 1
-# define LOCALE_WORKS 1
+# define HAVE_LOCALE_H 1
+# define HAVE_LANGINFO_CODESET 1
 #endif
 
-#if LOCALE_WORKS
-# include <langinfo.h>
+#if HAVE_LOCALE_H
 # include <locale.h>
 #endif
 
+#if HAVE_LANGINFO_CODESET
+# include <langinfo.h>
+#endif
+
 #ifdef _LIBC
 # define stringprep_locale_charset() nl_langinfo (CODESET)
 #else
@@ -79,7 +83,7 @@ stringprep_locale_charset (void)
   if (charset && *charset)
     return charset;
 
-# ifdef LOCALE_WORKS
+# ifdef HAVE_LANGINFO_CODESET
   charset = nl_langinfo (CODESET);
 
   if (charset && *charset)
