@@ -1,5 +1,5 @@
-/* tst_idna2.c	Self tests for idna_to_ascii_8z().
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+/* tst_idna2.c --- Self tests for idna_to_ascii_8z().
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -15,11 +15,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GNU Libidn; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  *
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -473,9 +473,14 @@ doit (void)
 
       if (debug)
 	{
+	  uint32_t *p;
+	  size_t len;
 	  printf ("in: %s\n", idna[i].in);
 	  hexprint (idna[i].in, strlen (idna[i].in));
 	  escapeprint (idna[i].in, strlen (idna[i].in));
+	  p = stringprep_utf8_to_ucs4 (idna[i].in, -1, &len);
+	  ucs4print (p, len);
+	  free (p);
 	}
 
       rc = idna_to_ascii_8z (idna[i].in, &out,
